; External routines needed
;
; Astronomy Users Library - http://idlastro.gsfc.nasa.gov/homepage.html
;    readfits,sxpar
;
; Buie Library - http://www.boulder.swri.edu/~buie/idl
;    blurmap,render,setwin
;
; Note that these are only the routines directly called by this sample script.
;   These routines call other routines in these libraries as well.  The
;   simplest thing to do to get this script to work is to download these two
;   libraries and make sure they are in your IDL_PATH.
;
; Execute this with: @sample at the IDL command line, .set, .val, and .ptr
;   files must be in the current directory.
;

fnset = 'vmap.set'

; pre-define string variables for I/O
filter=''
plmaproot=''
chmaproot=''

; Read in map information.
openr, lun, fnset, /get_lun
readf, lun, filter, format='(a)'
readf, lun, plmaproot, format='(a)'
readf, lun, plholes, plpg, plb0, plthetabar, plradius
readf, lun, chmaproot, format='(a)'
readf, lun, chholes, chpg, chb0, chthetabar, chradius
free_lun, lun

; Load the Pluto single-scattering albedo map
fnval = plmaproot+'.val'
fnptr = plmaproot+'.ptr'
plval = readfits(fnval,vhdr,/silent)
plptr = readfits(fnptr,phdr,/silent)
plnx  = sxpar(vhdr,'MAP_NX')
plny  = sxpar(vhdr,'MAP_NY')
null  = float(sxpar(vhdr,'MAP_NVAL'))
plmap = replicate(null,plnx,plny)
z = where(plptr ge 0 and plptr lt n_elements(plmap))
plmap[z] = plval[plptr[z]]
blurrad = 15.0 ; do not modify this value
mapfac  = 20
blurmap,plmap,blurrad,bplmap,outsize=[plnx*mapfac,plny*mapfac]

; Load the Charon single-scattering albedo map
fnval = chmaproot+'.val'
fnptr = chmaproot+'.ptr'
chval = readfits(fnval,vhdr,/silent)
chptr = readfits(fnptr,phdr,/silent)
chnx  = sxpar(vhdr,'MAP_NX')
chny  = sxpar(vhdr,'MAP_NY')
null  = float(sxpar(vhdr,'MAP_NVAL'))
chmap = replicate(null,chnx,chny)
z = where(chptr ge 0 and chptr lt n_elements(chmap))
chmap[z] = chval[chptr[z]]
blurrad = 30.0 ; do not modify this value
mapfac  = 20
blurmap,chmap,blurrad,bchmap,outsize=[chnx*mapfac,chny*mapfac]

; At this point, bplmap and bchmap are arrays containing the single-scattering
;  albedo maps of Pluto and Charon, respectively.  The following code shows
;  an example of taking this map and rendering a globe for each.

dw = 200      ; half-width of image array to render
ars = 2*dw+1 ; full width, force value to be odd to be nice
scale = 2.0*plradius/ars*1.15   ; km/pixel

pole = 0.0 ; projected angle of Pluto's north pole on image
selat = 33.0
selon = 270.0
sslat = 34.0
sslon = 270.0

render,bplmap,plradius,scale,pole,selat,selon,sslat,sslon,ars,ars,plimage, $
      hap2=[plholes,plpg,plb0,plthetabar/!radeg],/nodisplay,/silent

setwin,1,xsize=ars,ysize=ars
tv,bytscl(plimage,min=0.,max=1.2,top=255)

render,bchmap,chradius,scale,pole,selat,selon,sslat,sslon,ars,ars,chimage, $
      hap2=[chholes,chpg,chb0,chthetabar/!radeg],/nodisplay,/silent

setwin,2,xsize=ars,ysize=ars
tv,bytscl(chimage,min=0.,max=1.2,top=255)
